<?php

namespace Teknisa\FIN\Modules\MovimentacaoBancaria\Controllers;

use Teknisa\FIN\Modules\MovimentacaoBancaria\Services\Bco01500RecontabilizacaoDeTransferenciaService;
use Teknisa\FIN\Controllers\TeknisaCrud;
use Teknisa\Libs\Util\Masks\Masks;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Exception;


class Bco01500RecontabilizacaoDeTransferenciaController extends TeknisaCrud {
 
    protected $dataSourceName, $masks, $service;
    
    public function __construct($crudService, $parameterBag, Bco01500RecontabilizacaoDeTransferenciaService $service, Masks $masks) {
        $this->service = $service;
        $this->masks = $masks;
        parent::__construct($crudService, $parameterBag);
    }
    
    public function recontabilizarTransferencias(DTO\Request\DataSet $request, DTO\Response $response) {
        
        $rows = $request->getDataSet()->getRows();
        try {
            $this->service->recontabilizarTransferencias($rows, $response);
        } catch(\Exception $e) {
            $response->setStatus(Response::STATUS_ERROR);
        }
        
    }
    
    public function findTransferencias(DTO\Request\Filter $request, DTO\Response $response) {
        
        $this->dataSourceName = 'recontabilizacao_de_transferencia_transferencias';
        parent::find($request, $response);
        $dataSets = $response->getDataSets();
        
        if(!empty($dataSets)){
            $rows = $dataSets[0]->getRows();
            for($i = 0; count($rows) > $i; $i++){

                //Retira pontos (.) e traços (-) da mascará para comparação de caracteres
                $matches = array();
                preg_match_all('/[^-.]*/',$rows[$i]['CDPICTAGEN'], $matches);
                $unmaskedString = implode('', $matches[0]);

                if(strlen($rows[$i]['CDAGENCIA']) === strlen($unmaskedString)) {
                    $rows[$i]['CDAGENCIAMASK'] = $this->masks->mask($rows[$i]['CDAGENCIA'], $rows[$i]['CDPICTAGEN']);
                } else {
                    $rows[$i]['CDAGENCIAMASK'] = $rows[$i]['CDAGENCIA'];
                }

                //Retira pontos (.) e traços (-) da mascará para comparação de caracteres
                $matches = array();
                preg_match_all('/[^-.]*/',$rows[$i]['CDPICTCONT'], $matches);
                $unmaskedString = implode('', $matches[0]);

                if (strlen($rows[$i]['CDCONTCORR']) === strlen($unmaskedString)) {
                    $rows[$i]['CDCONTCORRMASK'] = $this->masks->mask($rows[$i]['CDCONTCORR'], $rows[$i]['CDPICTCONT']);
                } else {
                    $rows[$i]['CDCONTCORRMASK'] = $rows[$i]['CDCONTCORR'];
                } 
            }
            $newDataSet = new DataSet($this->dataSourceName, $rows);
            $response->setDataSets(array($newDataSet));
        }
    }
    
    public function findContas(DTO\Request\Filter $request, DTO\Response $response) {
        
        $this->dataSourceName = 'recontabilizacao_de_transferencia_conta';
        parent::find($request, $response);
        $dataSets = $response->getDataSets();
        
        if(!empty($dataSets)){
            $rows = $dataSets[0]->getRows();
            for($i = 0; count($rows) > $i; $i++){

                //Retira pontos (.) e traços (-) da mascará para comparação de caracteres
                $matches = array();
                preg_match_all('/[^-.]*/',$rows[$i]['CDPICTAGEN'], $matches);
                $unmaskedString = implode('', $matches[0]);

                if(strlen($rows[$i]['CDAGENCIA']) === strlen($unmaskedString)) {
                    $rows[$i]['CDAGENCIAMASK'] = $this->masks->mask($rows[$i]['CDAGENCIA'], $rows[$i]['CDPICTAGEN']);
                } else {
                    $rows[$i]['CDAGENCIAMASK'] = $rows[$i]['CDAGENCIA'];
                }

                //Retira pontos (.) e traços (-) da mascará para comparação de caracteres
                $matches = array();
                preg_match_all('/[^-.]*/',$rows[$i]['CDPICTCONT'], $matches);
                $unmaskedString = implode('', $matches[0]);

                if (strlen($rows[$i]['CDCONTCORR']) === strlen($unmaskedString)) {
                    $rows[$i]['CDCONTCORRMASK'] = $this->masks->mask($rows[$i]['CDCONTCORR'], $rows[$i]['CDPICTCONT']);
                } else {
                    $rows[$i]['CDCONTCORRMASK'] = $rows[$i]['CDCONTCORR'];
                } 
            }
            $newDataSet = new DataSet($this->dataSourceName, $rows);
            $response->setDataSets(array($newDataSet));
        }
    }
    
   
}
